import 'package:flutter/material.dart';
import 'package:tivio_sdk/tivio.dart';

class PrintTivioObject extends StatefulWidget {
  final String _label;
  final Function(String text) _handleOnPressed;

  PrintTivioObject(this._label, this._handleOnPressed);

  @override
  createState() => _PrintTivioObjectState();
}

class _PrintTivioObjectState extends State<PrintTivioObject> {
  final textController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return Column(children: [
      Column(crossAxisAlignment: CrossAxisAlignment.start, children: [
        Container(
          padding: EdgeInsets.only(top: 15),
          child: Text(
            'Get ${widget._label} by id:',
            style: TextStyle(
              fontSize: 16,
              fontWeight: FontWeight.bold,
            ),
          ),
        ),
        TextField(
          controller: textController,
        ),
        TextButton(
          child: Text('Print ${widget._label}'),
          onPressed: () => widget._handleOnPressed(textController.text),
        ),
      ])
    ]);
  }

  @override
  void dispose() {
    textController.dispose();
    super.dispose();
  }
}

class GetDataByIdPage extends StatelessWidget {
  final Tivio _tivio;

  GetDataByIdPage(this._tivio);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text('Get data by id')),
      body: SingleChildScrollView(
        child: Column(
          children: [
            PrintTivioObject(
              'widget',
              (String text) async {
                var tivioWidget = await _tivio.getWidgetById(text);
                print('Tivio widget:');
                print(tivioWidget.id);
                print(tivioWidget.name);
              },
            ),
            PrintTivioObject(
              'channel',
              (String text) async {
                var channel = await _tivio.getChannelById(text);
                print('Tivio channel:');
                print(channel.id);
                print(channel.name);
              },
            ),
            PrintTivioObject(
              'video',
              (String text) async {
                var video = await _tivio.getVideoById(text);
                print('Tivio video:');
                print(video.id);
                print(video.name);
                print(video.url.hls);
              },
            ),
          ],
        ),
      ),
    );
  }
}
