import 'package:flutter/material.dart';
import 'package:tivio_sdk/tivio.dart';
import 'package:flutter_dotenv/flutter_dotenv.dart';

class TivioVideoPage extends StatefulWidget {
  final String url;
  final String name;
  final Duration duration;

  TivioVideoPage(this.url, this.name, this.duration);

  @override
  _TivioVideoPageState createState() => _TivioVideoPageState();
}

class _TivioVideoPageState extends State<TivioVideoPage> {
  bool _isTivioInitialized = false;
  Tivio _tivio;

  @override
  void initState() {
    super.initState();
    initializeTivio();
  }

  initializeTivio() async {
    // TD move _tivio to some global space
    _tivio = await initTivio(secret: DotEnv().env['TIVIO_SECRET'], language: TivioLanguages.cs);

    setState(() {
      _isTivioInitialized = true;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: Text(this.widget.name)),
      body: Container(
        child: (_isTivioInitialized)
            ? TivioPlayer(
                playerId: '1',
                tivio: _tivio,
                source: TivioPlayerChannelSource(
                  this.widget.url,
                  this.widget.name,
                  Duration(),
                  this.widget.duration,
                ),
              )
            : Text('initializing...'),
      ),
    );
  }
}
