import 'bridge.dart';

class TivioDataWidget {
  String id;
  String name;
  Bridge _bridge;

  TivioDataWidget(String id, String name, Bridge bridge) {
    this.id = id;
    this.name = name;
    _bridge = bridge;
  }

  Future<List<TivioDataVideo>> getRecentVideos() {
    return this._bridge.widgetGetRecentVideos(this.id);
  }

  subscribeToChannels(Function(TivioDataChannel) callback) {
    return this._bridge.subscribeToChannels(this.id, callback);
  }

  unsubscribeToChannels() {
    // TD add support of unsubscribing concrete callback
    this._bridge.unsubscribeToChannels();
  }
}

class _ChannelImages {
  String logo;
  String cover;

  _ChannelImages(String logo, String cover) {
    this.logo = logo;
    this.cover = cover;
  }
}

class TivioDataChannel {
  String id;
  String name;
  _ChannelImages images;
  Bridge _bridge;

  TivioDataChannel(String id, String name, String logo, String cover, Bridge bridge) {
    this.id = id;
    this.name = name;
    this.images = new _ChannelImages(logo, cover);
    _bridge = bridge;
  }

  Future<List<TivioDataVideo>> getRecentVideos() {
    return this._bridge.channelGetRecentVideos(this.id);
  }

  subscribeToSections(Function(TivioDataSection) callback) {
    return this._bridge.subscribeToSections(this.id, callback);
  }

  unsubscribeToSections() {
    this._bridge.unsubscribeToSections();
  }
}

class TivioDataSection {
  String id;
  String name;
  Bridge _bridge;

  TivioDataSection(String id, String name, Bridge bridge) {
    this.id = id;
    this.name = name;
    _bridge = bridge;
  }

  subscribeToVideos(Function(TivioDataVideo) callback) {
    return _bridge.subscribeToVideos(this.id, callback);
  }

  unsubscribeToVideos() {
    _bridge.unsubscribeToVideos();
  }
}

class _Url {
  String hls;

  _Url(this.hls);
}

class _VideoImages {
  String cover;

  _VideoImages(this.cover);
}

class _Monetization {
  num price;
  String type;

  _Monetization(this.price, this.type);
}

class TivioDataPlaylistItem {
  String name;
  _Url url;
  Duration duration;

  TivioDataPlaylistItem(String name, String url, Duration duration) {
    this.name = name;
    this.url = _Url(url);
    this.duration = duration;
  }
}

class TivioDataVideo {
  String id;
  String name;
  Duration duration;
  DateTime created;
  _Url url;
  _VideoImages images;
  bool isPlaylist;
  List<TivioDataPlaylistItem> playlistItems = [];
  _Monetization monetization;

  TivioDataVideo(
    String id,
    String name,
    Duration duration,
    DateTime created,
    String url,
    String cover,
    bool isPlaylist,
    List<TivioDataPlaylistItem> playlistItems,
    Map monetization,
  ) {
    this.id = id;
    this.name = name;
    this.duration = duration;
    this.created = created;
    this.url = _Url(url);
    this.images = new _VideoImages(cover);
    this.isPlaylist = isPlaylist;
    this.playlistItems = playlistItems;
    if (monetization != null) {
      this.monetization = _Monetization(monetization['price'], monetization['type']);
    }
  }
}

class TivioDataPagination<T> {
  List<T> records;
  bool hasNextPage;

  TivioDataPagination(List<T> records, bool hasNextPage) {
    this.records = records;
    this.hasNextPage = hasNextPage;
  }
}
