import '../bridge.dart';
import '../player/tivio_player_input_source.dart';
import '../utils/enum.dart';

enum TivioPlayerState {
  idle,
  buffering,
  paused,
  playing,
}

class TivioPlayerWrapperController {
  final Function play;
  final Function pause;
  final Function seekTo;
  final Function openAndPlay;

  TivioPlayerWrapperController(
    this.play,
    this.pause,
    this.seekTo,
    this.openAndPlay,
  );
}

class TivioPlayerWrapper {
  final String id;
  final Bridge _bridge;

  TivioPlayerWrapper(this.id, this._bridge);

  register(TivioPlayerWrapperController controller) async {
    await _bridge.playerRegister(this.id);

    _bridge.onPlayerPlay(
      id,
      controller.play,
    );

    _bridge.onPlayerPause(
      id,
      controller.pause,
    );

    _bridge.onPlayerSeekTo(
      id,
      (payload) {
        print(payload);
        return controller.seekTo(
          Duration(
            milliseconds: payload['timestampMs'],
          ),
        );
      },
    );

    _bridge.onPlayerChangeSource(
      id,
      (payload) {
        String sourceType = payload['source']['type'];
        switch (sourceType) {
          case 'channel':
            {
              controller.openAndPlay(TivioPlayerChannelSource(
                payload['source']['uri'],
                payload['source']['name'],
                Duration(milliseconds: payload['source']['from']),
                Duration(milliseconds: payload['source']['to']),
              ));
            }
            break;
          case 'advertisement':
            {
              controller.openAndPlay(TivioPlayerAdSource(
                payload['source']['uri'],
                payload['source']['name'],
                Duration(milliseconds: payload['source']['duration']),
              ));
            }
            break;
          default:
            {
              throw Exception('Unknown source type $sourceType');
            }
        }
      },
    );
  }

  play() {
    return _bridge.playerPlay(id);
  }

  pause() {
    return _bridge.playerPause(id);
  }

  openAndPlay(TivioPlayerInputSource source) {
    return _bridge.playerOnSourceChanged(
      id,
      source.toObject(),
    );
  }

  seekTo(Duration time) {
    return _bridge.playerSeekTo(id, time.inMilliseconds);
  }

  onTimeChanged(Duration time) {
    return _bridge.playerOnTimeChanged(id, time.inMilliseconds);
  }

  onStateChanged(TivioPlayerState state) {
    return _bridge.playerOnStateChanged(id, enumToString(state));
  }
}
