library tivio;
import 'package:meta/meta.dart';
import 'dart:async';
import 'bridge.dart';
import 'dto.dart';
import 'player/tivio_player_wrapper.dart';
import 'utils/enum.dart';
export 'mixins/tivio_widget.dart';
export 'mixins/tivio_channels.dart';
export 'mixins/tivio_sections.dart';
export 'mixins/tivio_videos.dart';
export 'dto.dart';
export 'player/tivio_player.dart';
export 'player/tivio_player_controller.dart';
export 'player/tivio_player_input_source.dart';
export 'player/tivio_player_wrapper.dart';

enum TivioLanguages {
  cs,
  en,
  sk,
  de,
  pl,
}

class Tivio {
  final String _appId;
  final TivioLanguages _language;
  final Bridge _bridge = Bridge();

  Tivio(this._appId, this._language);

  Future<Tivio> init() async {
    await _bridge.init(_appId, enumToString(_language));
    return this;
  }

  setLanguage(TivioLanguages language) => _bridge.setLanguage(enumToString(language));

  Future<TivioPlayerWrapper> getPlayer(String id) => _bridge.getPlayer(id);

  Future<TivioDataWidget> getWidgetById(String id) => _bridge.getWidgetById(id);

  Future<TivioDataChannel> getChannelById(String id) => _bridge.getChannelById(id);

  Future<TivioDataSection> getSectionById(String id) => throw new Exception('Not implemented yet');

  Future<TivioDataVideo> getVideoById(String id) => _bridge.getVideoById(id);

  Future<TivioDataPagination<TivioDataChannel>> searchChannels({@required String query, int limit = 10}) {
    return _bridge.searchChannels(query, limit);
  }

  Future<TivioDataPagination<TivioDataVideo>> searchVideos({@required String query, int limit = 10}) {
    return _bridge.searchVideos(query, limit);
  }

  subscribeToWidgets(String widgetId, Function(TivioDataWidget) callback) {
    return _bridge.subscribeToWidgets(widgetId, callback);
  }

  unsubscribeToWidgets() {
    _bridge.unsubscribeToWidgets();
  }
}

Future<Tivio> initTivio({String secret, TivioLanguages language}) {
  return Tivio(secret, language).init();
}
